==> prometheus-annotations-2.7.0-sources.jar: io/dekorate/prometheus/model/EndpointBuilder.java <==
package io.dekorate.prometheus.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EndpointBuilder extends io.dekorate.prometheus.model.EndpointFluentImpl<io.dekorate.prometheus.model.EndpointBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.prometheus.model.Endpoint,io.dekorate.prometheus.model.EndpointBuilder>{
  public EndpointBuilder() {
    this(false);
  }
  public EndpointBuilder(java.lang.Boolean validationEnabled) {
    this(new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,io.dekorate.prometheus.model.Endpoint instance) {
    this(fluent, instance, false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,io.dekorate.prometheus.model.Endpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPort(instance.getPort()); 
    fluent.withPath(instance.getPath()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withHonorLabels(instance.isHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public EndpointBuilder(io.dekorate.prometheus.model.Endpoint instance) {
    this(instance,false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.Endpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.isHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.prometheus.model.EndpointFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.prometheus.model.Endpoint build() {
    Endpoint buildable = new Endpoint(fluent.getPort(),fluent.getPath(),fluent.getInterval(),fluent.isHonorLabels());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EndpointBuilder that = (EndpointBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> prometheus-annotations-2.11.6-sources.jar: io/dekorate/prometheus/model/EndpointBuilder.java <==
package io.dekorate.prometheus.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EndpointBuilder extends EndpointFluentImpl<EndpointBuilder> implements VisitableBuilder<io.dekorate.prometheus.model.Endpoint,EndpointBuilder>{
  public EndpointBuilder() {
    this(false);
  }
  public EndpointBuilder(Boolean validationEnabled) {
    this(new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,io.dekorate.prometheus.model.Endpoint instance) {
    this(fluent, instance, false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.EndpointFluent<?> fluent,io.dekorate.prometheus.model.Endpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPort(instance.getPort()); 
    fluent.withPath(instance.getPath()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withHonorLabels(instance.isHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public EndpointBuilder(io.dekorate.prometheus.model.Endpoint instance) {
    this(instance,false);
  }
  public EndpointBuilder(io.dekorate.prometheus.model.Endpoint instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPort(instance.getPort()); 
    this.withPath(instance.getPath()); 
    this.withInterval(instance.getInterval()); 
    this.withHonorLabels(instance.isHonorLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.prometheus.model.EndpointFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.prometheus.model.Endpoint build() {
    Endpoint buildable = new Endpoint(fluent.getPort(),fluent.getPath(),fluent.getInterval(),fluent.isHonorLabels());
    return buildable;
  }
  
}
